@@ -16,10 +16,10 @@ class User(Document):
 class TestEmbeddedDocumentField(AsyncTestCase):
     def test_cant_create_embedded_field_of_wrong_embedded_type(self):
         try:
-            EmbeddedDocumentField(embedded_document_type="test")
+            EmbeddedDocumentField(embedded_document_type=10).validate(None)
         except ValueError:
             err = sys.exc_info()[1]
-            expect(err).to_have_an_error_message_of("The field 'embedded_document_type' argument must be a subclass of Document, not 'test'.")
+            expect(err).to_have_an_error_message_of("The field 'embedded_document_type' argument must be a subclass of Document, not '10'.")
         else:
             assert False, "Should not have gotten this far"
 
@@ -28,6 +28,10 @@ class TestEmbeddedDocumentField(AsyncTestCase):
         expect(field.db_field).to_equal("test")
         expect(field._embedded_document_type).to_equal(User)
 
+    def test_create_embedded_document_field_with_string_type(self):
+        field = EmbeddedDocumentField(embedded_document_type="tests.fields.test_embedded_document_field.User")
+        expect(field.embedded_type).to_equal(User)
+
     def test_to_son(self):
         field = EmbeddedDocumentField(db_field="test", embedded_document_type=User)
 
